==> cognito-local-3.20.0.tgz: package/lib/errors.js <==
var __defProp = Object.defineProperty;
var __markAsModule = (target) => __defProp(target, "__esModule", { value: true });
var __export = (target, all) => {
  __markAsModule(target);
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
__export(exports, {
  CodeMismatchError: () => CodeMismatchError,
  CognitoError: () => CognitoError,
  GroupNotFoundError: () => GroupNotFoundError,
  InvalidLambdaResponseError: () => InvalidLambdaResponseError,
  InvalidParameterError: () => InvalidParameterError,
  InvalidPasswordError: () => InvalidPasswordError,
  NotAuthorizedError: () => NotAuthorizedError,
  PasswordResetRequiredError: () => PasswordResetRequiredError,
  ResourceNotFoundError: () => ResourceNotFoundError,
  UnexpectedLambdaExceptionError: () => UnexpectedLambdaExceptionError,
  UnsupportedError: () => UnsupportedError,
  UserLambdaValidationError: () => UserLambdaValidationError,
  UserNotFoundError: () => UserNotFoundError,
  UsernameExistsError: () => UsernameExistsError
});
class UnsupportedError extends Error {
}
class CognitoError extends Error {
  constructor(code, message) {
    super(message);
    this.code = `CognitoLocal#${code}`;
  }
}
class NotAuthorizedError extends CognitoError {
  constructor() {
    super("NotAuthorizedException", "User not authorized");
  }
}
class UserNotFoundError extends CognitoError {
  constructor(message = "User not found") {
    super("UserNotFoundException", message);
  }
}
class UsernameExistsError extends CognitoError {
  constructor() {
    super("UsernameExistsException", "User already exists");
  }
}
class CodeMismatchError extends CognitoError {
  constructor() {
    super("CodeMismatchException", "Incorrect confirmation code");
  }
}
class InvalidPasswordError extends CognitoError {
  constructor() {
    super("InvalidPasswordException", "Invalid password");
  }
}
class PasswordResetRequiredError extends CognitoError {
  constructor() {
    super("PasswordResetRequiredException", "Password reset required");
  }
}
class ResourceNotFoundError extends CognitoError {
  constructor(message) {
    super("ResourceNotFoundException", message ?? "Resource not found");
  }
}
class GroupNotFoundError extends ResourceNotFoundError {
  constructor() {
    super("Group not found");
  }
}
class UnexpectedLambdaExceptionError extends CognitoError {
  constructor() {
    super("UnexpectedLambdaExceptionException", "Unexpected error when invoking lambda");
  }
}
class UserLambdaValidationError extends CognitoError {
  constructor(message) {
    super("UserLambdaValidationException", message ?? "Lambda threw an exception");
  }
}
class InvalidLambdaResponseError extends CognitoError {
  constructor() {
    super("InvalidLambdaResponseException", "Invalid Lambda response");
  }
}
class InvalidParameterError extends CognitoError {
  constructor(message = "Invalid parameter") {
    super("InvalidParameterException", message);
  }
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  CodeMismatchError,
  CognitoError,
  GroupNotFoundError,
  InvalidLambdaResponseError,
  InvalidParameterError,
  InvalidPasswordError,
  NotAuthorizedError,
  PasswordResetRequiredError,
  ResourceNotFoundError,
  UnexpectedLambdaExceptionError,
  UnsupportedError,
  UserLambdaValidationError,
  UserNotFoundError,
  UsernameExistsError
});

==> cognito-local-3.21.2.tgz: package/lib/errors.js <==
var __defProp = Object.defineProperty;
var __markAsModule = (target) => __defProp(target, "__esModule", { value: true });
var __export = (target, all) => {
  __markAsModule(target);
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
__export(exports, {
  CodeMismatchError: () => CodeMismatchError,
  CognitoError: () => CognitoError,
  GroupNotFoundError: () => GroupNotFoundError,
  InvalidLambdaResponseError: () => InvalidLambdaResponseError,
  InvalidParameterError: () => InvalidParameterError,
  InvalidPasswordError: () => InvalidPasswordError,
  NotAuthorizedError: () => NotAuthorizedError,
  PasswordResetRequiredError: () => PasswordResetRequiredError,
  ResourceNotFoundError: () => ResourceNotFoundError,
  UnexpectedLambdaExceptionError: () => UnexpectedLambdaExceptionError,
  UnsupportedError: () => UnsupportedError,
  UserLambdaValidationError: () => UserLambdaValidationError,
  UserNotFoundError: () => UserNotFoundError,
  UsernameExistsError: () => UsernameExistsError
});
class UnsupportedError extends Error {
}
class CognitoError extends Error {
  constructor(code, message) {
    super(message);
    this.code = `${code}`;
  }
}
class NotAuthorizedError extends CognitoError {
  constructor() {
    super("NotAuthorizedException", "User not authorized");
  }
}
class UserNotFoundError extends CognitoError {
  constructor(message = "User not found.") {
    super("UserNotFoundException", message);
  }
}
class UsernameExistsError extends CognitoError {
  constructor() {
    super("UsernameExistsException", "User already exists");
  }
}
class CodeMismatchError extends CognitoError {
  constructor() {
    super("CodeMismatchException", "Incorrect confirmation code");
  }
}
class InvalidPasswordError extends CognitoError {
  constructor() {
    super("InvalidPasswordException", "Invalid password");
  }
}
class PasswordResetRequiredError extends CognitoError {
  constructor() {
    super("PasswordResetRequiredException", "Password reset required");
  }
}
class ResourceNotFoundError extends CognitoError {
  constructor(message) {
    super("ResourceNotFoundException", message ?? "Resource not found");
  }
}
class GroupNotFoundError extends ResourceNotFoundError {
  constructor() {
    super("Group not found");
  }
}
class UnexpectedLambdaExceptionError extends CognitoError {
  constructor() {
    super("UnexpectedLambdaExceptionException", "Unexpected error when invoking lambda");
  }
}
class UserLambdaValidationError extends CognitoError {
  constructor(message) {
    super("UserLambdaValidationException", message ?? "Lambda threw an exception");
  }
}
class InvalidLambdaResponseError extends CognitoError {
  constructor() {
    super("InvalidLambdaResponseException", "Invalid Lambda response");
  }
}
class InvalidParameterError extends CognitoError {
  constructor(message = "Invalid parameter") {
    super("InvalidParameterException", message);
  }
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  CodeMismatchError,
  CognitoError,
  GroupNotFoundError,
  InvalidLambdaResponseError,
  InvalidParameterError,
  InvalidPasswordError,
  NotAuthorizedError,
  PasswordResetRequiredError,
  ResourceNotFoundError,
  UnexpectedLambdaExceptionError,
  UnsupportedError,
  UserLambdaValidationError,
  UserNotFoundError,
  UsernameExistsError
});
